Getting started
===============

If you haven't done so already, read :doc:`prerequisites` and follow the
applicable steps.


Processing the first waveform
-----------------------------

If you are new to swath processing, it may be informative to follow the
tutorial on (processing and) viewing a single waveform. While this is
not the kind of data that you will need to analyze a glaciers evolution,
this is its foundation. Knowledge about the smallest parts of the data
can help you understand the larger picture.

Find the tutorial in `scripts/tutorial__process_first_waveform.ipynb
<https://github.com/j-haacker/cryoswath/blob/main/scripts/tutorial__process_first_waveform.ipynb>`_.


Processing the first swath
--------------------------

Similar to viewing a single waveform, you might wonder how swath data of
a single track look like. Again, a single track will not tell you much
about a glacier's evolution, but it may help to understand higher level
data.

`scripts/tutorial__process_first_swath.ipynb
<https://github.com/j-haacker/cryoswath/blob/main/scripts/tutorial__process_first_swath.ipynb>`_
will give you a hand using cryoswath to process a single track and
visualize the data.


General step-by-step tutorial
-----------------------------

The general step-by-step tutorial takes you from processing a waveform
to producing a map of elevation change trends. It balances understanding
the background processes with quickly enabling to use cryoswath.

Find the notebook in `scripts/tutorial__general_step-by-step.ipynb
<https://github.com/j-haacker/cryoswath/blob/main/scripts/tutorial__general_step-by-step.ipynb>`_.
